Details
-------

Factor vector is a column of the factor matrix V, which is calculated as follows:

.. math::
    V = \Sigma^{-1} X^{T} U,

where X is a Hankel trajectory matrix, U is the matrix of eigenvectors and Sigma is a matrix of singular values.

See Also
--------

ssa, decompose